==> haskell-aeson-compat-0.3.9-23-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-compat
version: 0.3.9
id: aeson-compat-0.3.9-B1xSz3Gpi2f2L5QotGHApL
key: aeson-compat-0.3.9-B1xSz3Gpi2f2L5QotGHApL
license: BSD-3-Clause
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
author: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/aeson-compat#readme
synopsis: Compatibility layer for aeson
description:
    Compatibility layer for @aeson@
category: Web
abi: 9279798253c7a9fd60079ddc9e5663df
exposed: True
exposed-modules:
    Data.Aeson.Compat
import-dirs: /usr/lib/ghc-8.6.4/site-local/aeson-compat-0.3.9
library-dirs: /usr/lib/ghc-8.6.4/site-local/aeson-compat-0.3.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/aeson-compat-0.3.9
hs-libraries: HSaeson-compat-0.3.9-B1xSz3Gpi2f2L5QotGHApL
depends:
    aeson-1.4.2.0-3p7goNB3q4s1JbMrIJBuLL
    attoparsec-0.13.2.2-6cOh3sci63HJyadcbPhvpT
    attoparsec-iso8601-1.0.1.0-9oU4AXjcSv8BqTzy6TsQPl base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr bytestring-0.10.8.2
    containers-0.6.0.1 exceptions-0.10.1-7nkghZ77rTO8NZKanvk3XU
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    scientific-0.3.6.2-BVEhLkswVxa6jxFFJ9XwaR
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP text-1.2.3.1 time-1.8.0.2
    time-locale-compat-0.1.1.5-4Kz46WDKPmGDmYVdO1w5q7
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-aeson-compat/html/aeson-compat.haddock
haddock-html: /usr/share/doc/haskell-aeson-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-compat-0.3.9-24-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-compat
version: 0.3.9
id: aeson-compat-0.3.9-2ZcP84zNGV98V80hxmwJXG
key: aeson-compat-0.3.9-2ZcP84zNGV98V80hxmwJXG
license: BSD-3-Clause
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
author: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/aeson-compat#readme
synopsis: Compatibility layer for aeson
description:
    Compatibility layer for @aeson@
category: Web
abi: 4c1977eecfba64baba52d7341ab2e792
exposed: True
exposed-modules:
    Data.Aeson.Compat
import-dirs: /usr/lib/ghc-8.6.4/site-local/aeson-compat-0.3.9
library-dirs: /usr/lib/ghc-8.6.4/site-local/aeson-compat-0.3.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/aeson-compat-0.3.9
hs-libraries: HSaeson-compat-0.3.9-2ZcP84zNGV98V80hxmwJXG
depends:
    aeson-1.4.2.0-Avxlg2iWl9mA2BcbnSAv1Y
    attoparsec-0.13.2.2-6cOh3sci63HJyadcbPhvpT
    attoparsec-iso8601-1.0.1.0-9oU4AXjcSv8BqTzy6TsQPl base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr bytestring-0.10.8.2
    containers-0.6.0.1 exceptions-0.10.1-7nkghZ77rTO8NZKanvk3XU
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    scientific-0.3.6.2-BVEhLkswVxa6jxFFJ9XwaR
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP text-1.2.3.1 time-1.8.0.2
    time-locale-compat-0.1.1.5-4Kz46WDKPmGDmYVdO1w5q7
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-aeson-compat/html/aeson-compat.haddock
haddock-html: /usr/share/doc/haskell-aeson-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
